import { useState } from "react";
import {
  Dialog,
  DialogContent,
  TextField,
  Button,
  LinearProgress,
  Alert,
  Grid,
  styled
} from "@mui/material";

interface LoginFormProps {
  error?: string;
  loading?: boolean;
  className?: string;
  login: (username: string, password: string) => void;
}
export const LoginForm = styled(
  ({ error, loading, className, login }: LoginFormProps) => {
    const [username, setUsername] = useState("");
    const [password, setPassword] = useState("");

    return (
      <form className={`${className} CeuiLoginForm`}>
        <Grid
          container
          spacing={1}
        >
          <Grid
            item
            xs={12}
            md={12}
          >
            <TextField
              label="Username"
              variant="outlined"
              onChange={(e) => {
                setUsername(e.target.value);
              }}
              fullWidth
              autoFocus
              required
              className="CeuiLoginForm-UserName"
            />
          </Grid>
          <Grid
            item
            xs={12}
            md={12}
          >
            <TextField
              label="Password"
              variant="outlined"
              type="password"
              onChange={(e) => {
                setPassword(e.target.value);
              }}
              fullWidth
              required
              className="CeuiLoginForm-Password"
            />
          </Grid>
          <Grid
            item
            xs={12}
            md={12}
          >
            {error && (
              <Alert
                data-test="alert"
                severity="error"
                className="CeuiLoginForm-Error"
              >
                {error}
              </Alert>
            )}
          </Grid>
          <Grid
            item
            xs={12}
            md={12}
          >
            <Button
              data-test="submitButton"
              fullWidth
              variant="contained"
              color="primary"
              onClick={(e) => {
                e.preventDefault();
                login(username, password);
              }}
              type="submit"
              className="CeuiLoginForm-LoginButton"
            >
              Login
            </Button>
          </Grid>
          <Grid
            item
            xs={12}
            md={12}
          >
            {loading && (
              <LinearProgress
                data-test="progressbar"
                className="CeuiLoginForm-LoadingIndicator"
              />
            )}
          </Grid>
        </Grid>
      </form>
    );
  }
)({});

interface LoginDialogProps {
  open: boolean;
  error?: string;
  className?: string;
  loading?: boolean;
  login: (username: string, password: string) => void;
  handleClose: () => void;
}

export const LoginDialog = styled(
  ({
    open,
    error,
    className,
    loading,
    login,
    handleClose
  }: LoginDialogProps) => {
    return (
      <Dialog
        fullWidth
        open={open}
        onClose={handleClose}
        className={`${className} CeuiLoginDialog`}
      >
        <DialogContent>
          <LoginForm
            login={login}
            error={error}
            loading={loading}
          />
        </DialogContent>
      </Dialog>
    );
  }
)({});
