import { Alert, Button, Grid } from "@mui/material";
import { AlertTypes } from "./types";
import { useUniqueKeys } from "../../../hooks/useUniqueKeys";

type LowercaseAlertTypes = Lowercase<AlertTypes>;
export interface AlertBannerProps {
  type?: AlertTypes;
  message?: string;
  link?: string;
}

export const AlertBanner = ({ type, message, link }: AlertBannerProps) => {
  return (
    <Alert
      severity={(type?.toLowerCase() as LowercaseAlertTypes) ?? "info"}
      action={
        link && (
          <Button
            target="_blank"
            href={link}
            color="inherit"
            size="small"
          >
            More Info
          </Button>
        )
      }
    >
      {message}
    </Alert>
  );
};

export interface AlertBannerListProps {
  alerts?: AlertBannerProps[];
}

export const AlertBannerList = ({ alerts = [] }: AlertBannerListProps) => {
  const alertKeys = useUniqueKeys(alerts);
  return (
    <Grid
      id="ioc-alerts"
      container
      spacing={1}
    >
      {alertKeys &&
        alerts.map((alert, i) => (
          <Grid
            item
            xs={12}
            key={alertKeys[i]}
          >
            <AlertBanner {...alert} />
          </Grid>
        ))}
    </Grid>
  );
};
