import {
  TextField,
  Autocomplete as MuiAutocomplete,
  CircularProgress,
  TextFieldProps,
  AutocompleteProps as MuiAutocompleteProps
} from "@mui/material";

export interface AutocompleteProps<Value> {
  loading: boolean;
  autocompleteProps: MuiAutocompleteProps<Value, false, true, false>;
  textFieldProps: TextFieldProps;
}

/**
 * Wraps the MUI Autocomplete with default loading behaviors in async use cases.
 */
export const Autocomplete = <Value,>({
  loading,
  autocompleteProps,
  textFieldProps
}: AutocompleteProps<Value>) => {
  return (
    <MuiAutocomplete
      autoHighlight
      loading={loading}
      clearOnBlur={false}
      autoSelect
      {...autocompleteProps}
      renderInput={(params) => (
        <TextField
          {...params}
          {...textFieldProps}
          InputProps={{
            ...params.InputProps,
            endAdornment: (
              <>
                {loading && (
                  <CircularProgress
                    color="inherit"
                    size={20}
                  />
                )}
                {params.InputProps.endAdornment}
              </>
            )
          }}
        />
      )}
      options={loading ? [] : autocompleteProps.options}
    />
  );
};
