import { ReactNode } from "react";
import { Paper, Typography } from "@mui/material";
import { MemoryRouter } from "react-router-dom";
import { Meta } from "@storybook/react";
import {
  EllipsisText,
  EllipsisTextProps
} from "../../../components/common/EllipsisText";
import { ExternalLink, InternalLink } from "../../../components/common/Link";

export default {
  title: "Common/EllipsisText",
  component: EllipsisText
} as Meta<typeof EllipsisText>;

interface ContainerProps {
  children: ReactNode;
}

const Container = ({ children }: ContainerProps) => {
  return (
    <Paper sx={{ height: "100vh", padding: 2 }}>
      <Typography>The following text is too long:</Typography>
      <Paper
        sx={{ padding: 1, width: "190px" }}
        variant="outlined"
      >
        {children}
      </Paper>
      <Typography
        variant="body2"
        fontStyle="italic"
      >
        (hover over it to view!)
      </Typography>
    </Paper>
  );
};

const TextTemplate = ({ children, ...props }: EllipsisTextProps) => {
  return (
    <Container>
      <EllipsisText {...props}>{children}</EllipsisText>
    </Container>
  );
};

export const Default = (args: EllipsisTextProps) => <TextTemplate {...args} />;
Default.args = {
  children:
    "There's some really important information here but it is obscured!",
  TypographyProps: {
    variant: "body2"
  },
  TooltipProps: {
    placement: "right-end"
  }
};

const ExternalLinkTemplate = ({ children, ...props }: EllipsisTextProps) => {
  return (
    <MemoryRouter>
      <Container>
        <ExternalLink
          to="https://europeanspallationsource.se/"
          label={children}
        >
          <EllipsisText {...props}>{children}</EllipsisText>
        </ExternalLink>
      </Container>
    </MemoryRouter>
  );
};

export const ExternalLinkEllipsisText = (args: EllipsisTextProps) => (
  <ExternalLinkTemplate {...args} />
);
ExternalLinkEllipsisText.args = {
  ...Default.args
};

const InternalLinkTemplate = ({ children, ...props }: EllipsisTextProps) => {
  return (
    <MemoryRouter>
      <Container>
        <InternalLink
          to="/"
          label={children}
        >
          <EllipsisText {...props}>{children}</EllipsisText>
        </InternalLink>
      </Container>
    </MemoryRouter>
  );
};

export const InternalLinkEllipsisText = (args: EllipsisTextProps) => (
  <InternalLinkTemplate {...args} />
);
InternalLinkEllipsisText.args = {
  ...Default.args
};
