import { ReactNode } from "react";
import { MemoryRouter } from "react-router-dom";
import {
  ExternalButtonLink,
  ExternalLink,
  InternalButtonLink,
  InternalLink,
  InternalLinkProps,
  InternalButtonLinkProps,
  ExternalLinkProps,
  ExternalButtonLinkProps
} from "../../../components/common/Link";

export default {
  title: "Common/Link"
};

interface TemplateProps {
  children: ReactNode;
}

const Template = ({ children }: TemplateProps) => {
  return <MemoryRouter>{children}</MemoryRouter>;
};

export const Internal = (args: InternalLinkProps) => (
  <Template>
    <InternalLink {...args}>Navigate within app</InternalLink>
  </Template>
);
Internal.args = {
  to: "/",
  label: "Navigate internally to somewhere"
};

export const InternalButton = (args: InternalButtonLinkProps) => (
  <Template>
    <InternalButtonLink {...args}>Navigate within app</InternalButtonLink>
  </Template>
);
InternalButton.args = {
  ...Internal.args
};

export const External = (args: ExternalLinkProps) => (
  <Template>
    <ExternalLink {...args}>Visit External Website</ExternalLink>
  </Template>
);
External.args = {
  to: "https://europeanspallationsource.se/",
  label: "Visit our website"
};

export const ExternalButton = (args: ExternalButtonLinkProps) => (
  <Template>
    <ExternalButtonLink {...args}>Visit External Website</ExternalButtonLink>
  </Template>
);
ExternalButton.args = {
  ...External.args
};

export const LinkWithProps = (args: ExternalLinkProps) => (
  <Template>
    <ExternalLink {...args}>
      Visit External Website with custom props
    </ExternalLink>
  </Template>
);
LinkWithProps.args = {
  ...External.args,
  LinkProps: { sx: { color: "red", width: "100%", display: "block" } }
};

export const ButtonWithProps = (args: ExternalButtonLinkProps) => (
  <Template>
    <ExternalButtonLink {...args}>
      Visit External Website with custom props
    </ExternalButtonLink>
  </Template>
);
ButtonWithProps.args = {
  ...External.args,
  ButtonProps: { variant: "contained" }
};
