import { Meta } from "@storybook/react";
import { TextField } from "@mui/material";
import { Autocomplete } from "../../components/common/Autocomplete";

export default {
  title: "Fields/Autocomplete"
} as Meta<typeof Autocomplete>;

const data = [
  {
    name: "Fido",
    type: "dog",
    age: 2
  },
  {
    name: "Oscar",
    type: "cat",
    age: 3.1
  },
  {
    name: "Bud",
    type: "dog",
    age: 0.5
  }
];

interface AutocompleteProps {
  loading: boolean;
}

const Template = ({ loading, ...args }: AutocompleteProps) => {
  return (
    <Autocomplete
      loading={loading}
      autocompleteProps={{
        options: data,
        getOptionLabel: (option) => {
          return option?.name;
        },
        onChange: (event, value, reason) => {
          console.debug({ onChange: { event, value, reason } });
        },
        onInputChange: (event, value, reason) => {
          console.debug({ onChange: { event, value, reason } });
        },
        renderInput: (params) => {
          return <TextField {...params} />;
        }
      }}
      textFieldProps={{
        label: "My Autocomplete Input",
        variant: "outlined",
        required: true
      }}
      {...args}
    />
  );
};

export const Default = () => <Template loading={false} />;

export const Loading = () => <Template loading />;
